@@ -29,10 +29,9 @@ build_time_vars = {'ABIFLAGS': '',
  'CC': 'gcc -pthread',
  'CCSHARED': '-fPIC',
  'CFLAGS': '-fno-strict-overflow -Wsign-compare -DNDEBUG -O2 '
-           '-fno-reorder-blocks -I/usr/include -I/usr/include/readline '
-           '-I/usr/pkg/include -O2 -fno-reorder-blocks -I/usr/include '
-           '-I/usr/include/readline -I/usr/pkg/include -O2 -fno-reorder-blocks '
-           '-I/usr/include -I/usr/include/readline -I/usr/pkg/include',
+           '-fno-reorder-blocks -I/usr/include -I/usr/pkg/include -O2 '
+           '-fno-reorder-blocks -I/usr/include -I/usr/pkg/include -O2 '
+           '-fno-reorder-blocks -I/usr/include -I/usr/pkg/include',
  'CFLAGSFORSHARED': '-fPIC',
  'CFLAGS_ALIASING': '',
  'CFLAGS_NODIST': '',
@@ -42,14 +41,13 @@ build_time_vars = {'ABIFLAGS': '',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in '
                 'Makefile.pre.in',
  'CONFIGURE_CFLAGS': '-O2 -fno-reorder-blocks -I/usr/include '
-                     '-I/usr/include/readline -I/usr/pkg/include',
+                     '-I/usr/pkg/include',
  'CONFIGURE_CFLAGS_NODIST': '-std=gnu11 -Wextra -Wno-unused-parameter '
                             '-Wno-missing-field-initializers '
                             '-Wstrict-prototypes '
                             '-Werror=implicit-function-declaration '
                             '-fvisibility=hidden',
- 'CONFIGURE_CPPFLAGS': '-I/usr/include -I/usr/include/readline '
-                       '-I/usr/pkg/include',
+ 'CONFIGURE_CPPFLAGS': '-I/usr/include -I/usr/pkg/include',
  'CONFIGURE_LDFLAGS': '-L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib '
                       '-Wl,-R/usr/pkg/lib -L/usr/X11R7/lib '
                       '-Wl,-R/usr/X11R7/lib',
@@ -61,26 +59,24 @@ build_time_vars = {'ABIFLAGS': '',
                 "'--build=m68k--netbsdelf' '--host=m68k--netbsdelf' "
                 "'--mandir=/usr/pkg/man' '--enable-option-checking=yes' "
                 "'build_alias=m68k--netbsdelf' 'host_alias=m68k--netbsdelf' "
-                "'PKG_CONFIG=/tmp/pkgbuild/lang/python312/work.m68k/.tools/bin/pkg-config' "
+                "'PKG_CONFIG=/usr/pkgsrc/lang/python312/work.m68k/.tools/bin/pkg-config' "
                 "'PKG_CONFIG_PATH=' "
-                "'PKG_CONFIG_LIBDIR=/tmp/pkgbuild/lang/python312/work.m68k/.buildlink/lib/pkgconfig:/tmp/pkgbuild/lang/python312/work.m68k/.buildlink/share/pkgconfig' "
+                "'PKG_CONFIG_LIBDIR=/usr/pkgsrc/lang/python312/work.m68k/.buildlink/lib/pkgconfig:/usr/pkgsrc/lang/python312/work.m68k/.buildlink/share/pkgconfig' "
                 "'CC=gcc' 'CFLAGS=-O2 -fno-reorder-blocks -I/usr/include "
-                "-I/usr/include/readline -I/usr/pkg/include' "
-                "'LDFLAGS=-L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib "
-                "-Wl,-R/usr/pkg/lib -L/usr/X11R7/lib -Wl,-R/usr/X11R7/lib' "
-                "'LIBS=-lcrypt' 'CPPFLAGS=-I/usr/include "
-                "-I/usr/include/readline -I/usr/pkg/include'",
+                "-I/usr/pkg/include' 'LDFLAGS=-L/usr/lib -Wl,-R/usr/lib "
+                '-L/usr/pkg/lib -Wl,-R/usr/pkg/lib -L/usr/X11R7/lib '
+                "-Wl,-R/usr/X11R7/lib' 'LIBS=-lcrypt' 'CPPFLAGS=-I/usr/include "
+                "-I/usr/pkg/include'",
  'CONFINCLUDEDIR': '/usr/pkg/include',
  'CONFINCLUDEPY': '/usr/pkg/include/python3.12',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/tmp/pkgbuild/lang/python312/work.m68k/Python-3.12.6/coverage.info',
+ 'COVERAGE_INFO': '/usr/pkgsrc/lang/python312/work.m68k/Python-3.12.9/coverage.info',
  'COVERAGE_LCOV_OPTIONS': '--rc lcov_branch_coverage=1',
- 'COVERAGE_REPORT': '/tmp/pkgbuild/lang/python312/work.m68k/Python-3.12.6/lcov-report',
+ 'COVERAGE_REPORT': '/usr/pkgsrc/lang/python312/work.m68k/Python-3.12.9/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--rc lcov_branch_coverage=1 --branch-coverage '
                             '--title "CPython 3.12 LCOV report [commit $(shell '
                             ')]"',
- 'CPPFLAGS': '-I. -I./Include -I/usr/include -I/usr/include/readline '
-             '-I/usr/pkg/include -I/usr/include -I/usr/include/readline '
+ 'CPPFLAGS': '-I. -I./Include -I/usr/include -I/usr/pkg/include -I/usr/include '
              '-I/usr/pkg/include',
  'CXX': 'c++ -pthread',
  'DEEPFREEZE_C': 'Python/deepfreeze/deepfreeze.c',
@@ -122,7 +118,6 @@ build_time_vars = {'ABIFLAGS': '',
  'EXTRA_CFLAGS': '',
  'EXT_SUFFIX': '.so',
  'FILEMODE': 644,
- 'FLOAT_WORDS_BIGENDIAN': 1,
  'FREEZE_MODULE': './_bootstrap_python ./Programs/_freeze_module.py',
  'FREEZE_MODULE_BOOTSTRAP': './Programs/_freeze_module',
  'FREEZE_MODULE_BOOTSTRAP_DEPS': 'Programs/_freeze_module',
@@ -159,7 +154,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_BROKEN_UNSETENV': 0,
  'HAVE_BUILTIN_ATOMIC': 1,
  'HAVE_BZLIB_H': 1,
- 'HAVE_CHFLAGS': 1,
+ 'HAVE_CHFLAGS': 0,
  'HAVE_CHMOD': 1,
  'HAVE_CHOWN': 1,
  'HAVE_CHROOT': 1,
@@ -330,7 +325,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_KQUEUE': 1,
  'HAVE_LANGINFO_H': 1,
  'HAVE_LARGEFILE_SUPPORT': 1,
- 'HAVE_LCHFLAGS': 1,
+ 'HAVE_LCHFLAGS': 0,
  'HAVE_LCHMOD': 1,
  'HAVE_LCHOWN': 1,
  'HAVE_LIBB2': 0,
@@ -431,7 +426,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_PWRITE': 1,
  'HAVE_PWRITEV': 1,
  'HAVE_PWRITEV2': 0,
- 'HAVE_READLINE_READLINE_H': 1,
+ 'HAVE_READLINE_READLINE_H': 0,
  'HAVE_READLINK': 1,
  'HAVE_READLINKAT': 1,
  'HAVE_READV': 1,
@@ -440,7 +435,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_RENAMEAT': 1,
  'HAVE_RL_APPEND_HISTORY': 1,
  'HAVE_RL_CATCH_SIGNAL': 1,
- 'HAVE_RL_COMPDISP_FUNC_T': 0,
+ 'HAVE_RL_COMPDISP_FUNC_T': 1,
  'HAVE_RL_COMPLETION_APPEND_CHARACTER': 1,
  'HAVE_RL_COMPLETION_DISPLAY_MATCHES_HOOK': 1,
  'HAVE_RL_COMPLETION_MATCHES': 1,
@@ -555,6 +550,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_SYS_MODEM_H': 0,
  'HAVE_SYS_NDIR_H': 0,
  'HAVE_SYS_PARAM_H': 1,
+ 'HAVE_SYS_PIDFD_H': 0,
  'HAVE_SYS_POLL_H': 1,
  'HAVE_SYS_RANDOM_H': 1,
  'HAVE_SYS_RESOURCE_H': 1,
@@ -588,7 +584,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_TMPNAM_R': 0,
  'HAVE_TM_ZONE': 1,
  'HAVE_TRUNCATE': 1,
- 'HAVE_TTYNAME': 1,
+ 'HAVE_TTYNAME_R': 1,
  'HAVE_TZNAME': 0,
  'HAVE_UMASK': 1,
  'HAVE_UNAME': 1,
@@ -628,11 +624,11 @@ build_time_vars = {'ABIFLAGS': '',
                    '/usr/pkg/include/python3.12 /usr/pkg/include/python3.12',
  'INCLUDEDIR': '/usr/pkg/include',
  'INCLUDEPY': '/usr/pkg/include/python3.12',
- 'INSTALL': '/usr/bin/install -c -o pbulk -g users',
- 'INSTALL_DATA': '/usr/bin/install -c -o pbulk -g users -m 644',
- 'INSTALL_PROGRAM': '/usr/bin/install -c -s -o pbulk -g users -m 755',
- 'INSTALL_SCRIPT': '/usr/bin/install -c -o pbulk -g users -m 755',
- 'INSTALL_SHARED': '/usr/bin/install -c -o pbulk -g users -m 755',
+ 'INSTALL': '/usr/bin/install -c -o root -g wheel',
+ 'INSTALL_DATA': '/usr/bin/install -c -o root -g wheel -m 644',
+ 'INSTALL_PROGRAM': '/usr/bin/install -c -s -o root -g wheel -m 755',
+ 'INSTALL_SCRIPT': '/usr/bin/install -c -o root -g wheel -m 755',
+ 'INSTALL_SHARED': '/usr/bin/install -c -o root -g wheel -m 755',
  'INSTSONAME': 'libpython3.12.so.1.0',
  'IO_H': 'Modules/_io/_iomodule.h',
  'IO_OBJS': '\\',
@@ -657,34 +653,28 @@ build_time_vars = {'ABIFLAGS': '',
  'LIBDIR': '/usr/pkg/lib',
  'LIBEXPAT_A': 'Modules/expat/libexpat.a',
  'LIBEXPAT_CFLAGS': '-fno-strict-overflow -Wsign-compare -DNDEBUG -O2 '
-                    '-fno-reorder-blocks -I/usr/include '
-                    '-I/usr/include/readline -I/usr/pkg/include -O2 '
-                    '-fno-reorder-blocks -I/usr/include '
-                    '-I/usr/include/readline -I/usr/pkg/include -O2 '
-                    '-fno-reorder-blocks -I/usr/include '
-                    '-I/usr/include/readline -I/usr/pkg/include -std=gnu11 '
-                    '-Wextra -Wno-unused-parameter '
+                    '-fno-reorder-blocks -I/usr/include -I/usr/pkg/include -O2 '
+                    '-fno-reorder-blocks -I/usr/include -I/usr/pkg/include -O2 '
+                    '-fno-reorder-blocks -I/usr/include -I/usr/pkg/include '
+                    '-std=gnu11 -Wextra -Wno-unused-parameter '
                     '-Wno-missing-field-initializers -Wstrict-prototypes '
                     '-Werror=implicit-function-declaration '
                     '-fvisibility=hidden  -I./Include/internal -I. -I./Include '
-                    '-I/usr/include -I/usr/include/readline -I/usr/pkg/include '
-                    '-I/usr/include -I/usr/include/readline -I/usr/pkg/include '
-                    '-fPIC -fPIC',
+                    '-I/usr/include -I/usr/pkg/include -I/usr/include '
+                    '-I/usr/pkg/include -fPIC -fPIC',
  'LIBEXPAT_HEADERS': '\\',
  'LIBEXPAT_OBJS': '\\',
  'LIBHACL_CFLAGS': '-I./Modules/_hacl/include -D_BSD_SOURCE -D_DEFAULT_SOURCE '
                    '-fno-strict-overflow -Wsign-compare -DNDEBUG -O2 '
-                   '-fno-reorder-blocks -I/usr/include -I/usr/include/readline '
-                   '-I/usr/pkg/include -O2 -fno-reorder-blocks -I/usr/include '
-                   '-I/usr/include/readline -I/usr/pkg/include -O2 '
-                   '-fno-reorder-blocks -I/usr/include -I/usr/include/readline '
-                   '-I/usr/pkg/include -std=gnu11 -Wextra '
-                   '-Wno-unused-parameter -Wno-missing-field-initializers '
-                   '-Wstrict-prototypes -Werror=implicit-function-declaration '
-                   '-fvisibility=hidden  -I./Include/internal -I. -I./Include '
-                   '-I/usr/include -I/usr/include/readline -I/usr/pkg/include '
-                   '-I/usr/include -I/usr/include/readline -I/usr/pkg/include '
-                   '-fPIC -fPIC',
+                   '-fno-reorder-blocks -I/usr/include -I/usr/pkg/include -O2 '
+                   '-fno-reorder-blocks -I/usr/include -I/usr/pkg/include -O2 '
+                   '-fno-reorder-blocks -I/usr/include -I/usr/pkg/include '
+                   '-std=gnu11 -Wextra -Wno-unused-parameter '
+                   '-Wno-missing-field-initializers -Wstrict-prototypes '
+                   '-Werror=implicit-function-declaration -fvisibility=hidden  '
+                   '-I./Include/internal -I. -I./Include -I/usr/include '
+                   '-I/usr/pkg/include -I/usr/include -I/usr/pkg/include -fPIC '
+                   '-fPIC',
  'LIBHACL_HEADERS': '\\',
  'LIBHACL_SHA2_A': 'Modules/_hacl/libHacl_Hash_SHA2.a',
  'LIBHACL_SHA2_HEADERS': '\\',
@@ -693,19 +683,15 @@ build_time_vars = {'ABIFLAGS': '',
  'LIBMPDEC_A': 'Modules/_decimal/libmpdec/libmpdec.a',
  'LIBMPDEC_CFLAGS': '-I./Modules/_decimal/libmpdec -DCONFIG_32=1 -DANSI=1 '
                     '-fno-strict-overflow -Wsign-compare -DNDEBUG -O2 '
-                    '-fno-reorder-blocks -I/usr/include '
-                    '-I/usr/include/readline -I/usr/pkg/include -O2 '
-                    '-fno-reorder-blocks -I/usr/include '
-                    '-I/usr/include/readline -I/usr/pkg/include -O2 '
-                    '-fno-reorder-blocks -I/usr/include '
-                    '-I/usr/include/readline -I/usr/pkg/include -std=gnu11 '
-                    '-Wextra -Wno-unused-parameter '
+                    '-fno-reorder-blocks -I/usr/include -I/usr/pkg/include -O2 '
+                    '-fno-reorder-blocks -I/usr/include -I/usr/pkg/include -O2 '
+                    '-fno-reorder-blocks -I/usr/include -I/usr/pkg/include '
+                    '-std=gnu11 -Wextra -Wno-unused-parameter '
                     '-Wno-missing-field-initializers -Wstrict-prototypes '
                     '-Werror=implicit-function-declaration '
                     '-fvisibility=hidden  -I./Include/internal -I. -I./Include '
-                    '-I/usr/include -I/usr/include/readline -I/usr/pkg/include '
-                    '-I/usr/include -I/usr/include/readline -I/usr/pkg/include '
-                    '-fPIC -fPIC',
+                    '-I/usr/include -I/usr/pkg/include -I/usr/include '
+                    '-I/usr/pkg/include -fPIC -fPIC',
  'LIBMPDEC_HEADERS': '\\',
  'LIBMPDEC_OBJS': '\\',
  'LIBOBJDIR': 'Python/',
@@ -821,8 +807,9 @@ build_time_vars = {'ABIFLAGS': '',
  'MODULE_PYEXPAT_DEPS': '',
  'MODULE_PYEXPAT_LDFLAGS': '-lexpat',
  'MODULE_PYEXPAT_STATE': 'yes',
- 'MODULE_READLINE_CFLAGS': '',
- 'MODULE_READLINE_LDFLAGS': '-lreadline',
+ 'MODULE_READLINE_CFLAGS': '-I/usr/pkg/include',
+ 'MODULE_READLINE_LDFLAGS': '-Wl,-R/usr/pkg/lib -L/usr/pkg/lib -lreadline '
+                            '-ltermcap',
  'MODULE_READLINE_STATE': 'yes',
  'MODULE_RESOURCE_STATE': 'yes',
  'MODULE_SELECT_STATE': 'yes',
@@ -1029,8 +1016,7 @@ build_time_vars = {'ABIFLAGS': '',
  'MVWDELCH_IS_EXPRESSION': 1,
  'NO_AS_NEEDED': '-Wl,--no-as-needed',
  'OBJECT_OBJS': '\\',
- 'OPT': '-DNDEBUG -O2 -fno-reorder-blocks -I/usr/include '
-        '-I/usr/include/readline -I/usr/pkg/include',
+ 'OPT': '-DNDEBUG -O2 -fno-reorder-blocks -I/usr/include -I/usr/pkg/include',
  'PACKAGE_BUGREPORT': 0,
  'PACKAGE_NAME': 0,
  'PACKAGE_STRING': 0,
@@ -1067,50 +1053,43 @@ build_time_vars = {'ABIFLAGS': '',
  'PY_BUILTIN_HASHLIB_HASHES': '"md5,sha1,sha2,sha3,blake2"',
  'PY_BUILTIN_MODULE_CFLAGS': '-fno-strict-overflow -Wsign-compare -DNDEBUG -O2 '
                              '-fno-reorder-blocks -I/usr/include '
-                             '-I/usr/include/readline -I/usr/pkg/include -O2 '
+                             '-I/usr/pkg/include -O2 -fno-reorder-blocks '
+                             '-I/usr/include -I/usr/pkg/include -O2 '
                              '-fno-reorder-blocks -I/usr/include '
-                             '-I/usr/include/readline -I/usr/pkg/include -O2 '
-                             '-fno-reorder-blocks -I/usr/include '
-                             '-I/usr/include/readline -I/usr/pkg/include '
-                             '-std=gnu11 -Wextra -Wno-unused-parameter '
+                             '-I/usr/pkg/include -std=gnu11 -Wextra '
+                             '-Wno-unused-parameter '
                              '-Wno-missing-field-initializers '
                              '-Wstrict-prototypes '
                              '-Werror=implicit-function-declaration '
                              '-fvisibility=hidden  -I./Include/internal -I. '
-                             '-I./Include -I/usr/include '
-                             '-I/usr/include/readline -I/usr/pkg/include '
-                             '-I/usr/include -I/usr/include/readline '
-                             '-I/usr/pkg/include -fPIC -DPy_BUILD_CORE_BUILTIN',
+                             '-I./Include -I/usr/include -I/usr/pkg/include '
+                             '-I/usr/include -I/usr/pkg/include -fPIC '
+                             '-DPy_BUILD_CORE_BUILTIN',
  'PY_CFLAGS': '-fno-strict-overflow -Wsign-compare -DNDEBUG -O2 '
-              '-fno-reorder-blocks -I/usr/include -I/usr/include/readline '
-              '-I/usr/pkg/include -O2 -fno-reorder-blocks -I/usr/include '
-              '-I/usr/include/readline -I/usr/pkg/include -O2 '
-              '-fno-reorder-blocks -I/usr/include -I/usr/include/readline '
-              '-I/usr/pkg/include',
+              '-fno-reorder-blocks -I/usr/include -I/usr/pkg/include -O2 '
+              '-fno-reorder-blocks -I/usr/include -I/usr/pkg/include -O2 '
+              '-fno-reorder-blocks -I/usr/include -I/usr/pkg/include',
  'PY_CFLAGS_NODIST': '-std=gnu11 -Wextra -Wno-unused-parameter '
                      '-Wno-missing-field-initializers -Wstrict-prototypes '
                      '-Werror=implicit-function-declaration '
                      '-fvisibility=hidden  -I./Include/internal',
  'PY_COERCE_C_LOCALE': 1,
  'PY_CORE_CFLAGS': '-fno-strict-overflow -Wsign-compare -DNDEBUG -O2 '
-                   '-fno-reorder-blocks -I/usr/include -I/usr/include/readline '
-                   '-I/usr/pkg/include -O2 -fno-reorder-blocks -I/usr/include '
-                   '-I/usr/include/readline -I/usr/pkg/include -O2 '
-                   '-fno-reorder-blocks -I/usr/include -I/usr/include/readline '
-                   '-I/usr/pkg/include -std=gnu11 -Wextra '
-                   '-Wno-unused-parameter -Wno-missing-field-initializers '
-                   '-Wstrict-prototypes -Werror=implicit-function-declaration '
-                   '-fvisibility=hidden  -I./Include/internal -I. -I./Include '
-                   '-I/usr/include -I/usr/include/readline -I/usr/pkg/include '
-                   '-I/usr/include -I/usr/include/readline -I/usr/pkg/include '
-                   '-fPIC -DPy_BUILD_CORE',
+                   '-fno-reorder-blocks -I/usr/include -I/usr/pkg/include -O2 '
+                   '-fno-reorder-blocks -I/usr/include -I/usr/pkg/include -O2 '
+                   '-fno-reorder-blocks -I/usr/include -I/usr/pkg/include '
+                   '-std=gnu11 -Wextra -Wno-unused-parameter '
+                   '-Wno-missing-field-initializers -Wstrict-prototypes '
+                   '-Werror=implicit-function-declaration -fvisibility=hidden  '
+                   '-I./Include/internal -I. -I./Include -I/usr/include '
+                   '-I/usr/pkg/include -I/usr/include -I/usr/pkg/include -fPIC '
+                   '-DPy_BUILD_CORE',
  'PY_CORE_LDFLAGS': '-L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib '
                     '-Wl,-R/usr/pkg/lib -L/usr/X11R7/lib -Wl,-R/usr/X11R7/lib '
                     '-L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib '
                     '-Wl,-R/usr/pkg/lib -L/usr/X11R7/lib -Wl,-R/usr/X11R7/lib',
- 'PY_CPPFLAGS': '-I. -I./Include -I/usr/include -I/usr/include/readline '
-                '-I/usr/pkg/include -I/usr/include -I/usr/include/readline '
-                '-I/usr/pkg/include',
+ 'PY_CPPFLAGS': '-I. -I./Include -I/usr/include -I/usr/pkg/include '
+                '-I/usr/include -I/usr/pkg/include',
  'PY_ENABLE_SHARED': 1,
  'PY_HAVE_PERF_TRAMPOLINE': 0,
  'PY_LDFLAGS': '-L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib -Wl,-R/usr/pkg/lib '
@@ -1127,19 +1106,16 @@ build_time_vars = {'ABIFLAGS': '',
  'PY_SSL_DEFAULT_CIPHERS': 1,
  'PY_SSL_DEFAULT_CIPHER_STRING': 0,
  'PY_STDMODULE_CFLAGS': '-fno-strict-overflow -Wsign-compare -DNDEBUG -O2 '
-                        '-fno-reorder-blocks -I/usr/include '
-                        '-I/usr/include/readline -I/usr/pkg/include -O2 '
-                        '-fno-reorder-blocks -I/usr/include '
-                        '-I/usr/include/readline -I/usr/pkg/include -O2 '
-                        '-fno-reorder-blocks -I/usr/include '
-                        '-I/usr/include/readline -I/usr/pkg/include -std=gnu11 '
-                        '-Wextra -Wno-unused-parameter '
-                        '-Wno-missing-field-initializers -Wstrict-prototypes '
+                        '-fno-reorder-blocks -I/usr/include -I/usr/pkg/include '
+                        '-O2 -fno-reorder-blocks -I/usr/include '
+                        '-I/usr/pkg/include -O2 -fno-reorder-blocks '
+                        '-I/usr/include -I/usr/pkg/include -std=gnu11 -Wextra '
+                        '-Wno-unused-parameter -Wno-missing-field-initializers '
+                        '-Wstrict-prototypes '
                         '-Werror=implicit-function-declaration '
                         '-fvisibility=hidden  -I./Include/internal -I. '
-                        '-I./Include -I/usr/include -I/usr/include/readline '
-                        '-I/usr/pkg/include -I/usr/include '
-                        '-I/usr/include/readline -I/usr/pkg/include -fPIC',
+                        '-I./Include -I/usr/include -I/usr/pkg/include '
+                        '-I/usr/include -I/usr/pkg/include -fPIC',
  'PY_SUPPORT_TIER': 0,
  'Py_DEBUG': 0,
  'Py_ENABLE_SHARED': 1,
@@ -1151,7 +1127,7 @@ build_time_vars = {'ABIFLAGS': '',
  'READELF': '@READELF@',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/tmp/pkgbuild/lang/python312/work.m68k/Python-3.12.6',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/usr/pkgsrc/lang/python312/work.m68k/Python-3.12.9',
  'SCRIPTDIR': '/usr/pkg/lib',
  'SCRIPT_2TO3': 'build/scripts-3.12/2to3-3.12',
  'SCRIPT_IDLE': 'build/scripts-3.12/idle3.12',
@@ -1229,10 +1205,10 @@ build_time_vars = {'ABIFLAGS': '',
  'SYS_SELECT_WITH_SYS_TIME': 1,
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/tmp/pkgbuild/lang/python312/work.m68k/Python-3.12.6 '
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/usr/pkgsrc/lang/python312/work.m68k/Python-3.12.9 '
                './python -E',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/tmp/pkgbuild/lang/python312/work.m68k/Python-3.12.6 '
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/usr/pkgsrc/lang/python312/work.m68k/Python-3.12.9 '
                './python -E ./Tools/scripts/run_tests.py',
  'TESTSUBDIRS': 'idlelib/idle_test \\',
  'TESTTIMEOUT': 1200,
@@ -1262,8 +1238,8 @@ build_time_vars = {'ABIFLAGS': '',
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 1,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/tmp/pkgbuild/lang/python312/work.m68k/Python-3.12.6',
- 'abs_srcdir': '/tmp/pkgbuild/lang/python312/work.m68k/Python-3.12.6',
+ 'abs_builddir': '/usr/pkgsrc/lang/python312/work.m68k/Python-3.12.9',
+ 'abs_srcdir': '/usr/pkgsrc/lang/python312/work.m68k/Python-3.12.9',
  'datarootdir': '/usr/pkg/share',
  'exec_prefix': '/usr/pkg',
  'prefix': '/usr/pkg',
