@@ -3,9 +3,9 @@ build_time_vars = {'ABIFLAGS': '',
  'AC_APPLE_UNIVERSAL_BUILD': 0,
  'AIX_BUILDDATE': 0,
  'AIX_GENUINE_CPLUSPLUS': 0,
- 'ALIGNOF_LONG': 8,
- 'ALIGNOF_MAX_ALIGN_T': 16,
- 'ALIGNOF_SIZE_T': 8,
+ 'ALIGNOF_LONG': 4,
+ 'ALIGNOF_MAX_ALIGN_T': 8,
+ 'ALIGNOF_SIZE_T': 4,
  'ALT_SOABI': 0,
  'ANDROID_API_LEVEL': 0,
  'AR': 'ar',
@@ -23,15 +23,14 @@ build_time_vars = {'ABIFLAGS': '',
  'BOOTSTRAP_HEADERS': '\\',
  'BUILDEXE': '',
  'BUILDPYTHON': 'python',
- 'BUILD_GNU_TYPE': 'sparc64--netbsd',
+ 'BUILD_GNU_TYPE': 'armv6--netbsdelf-eabihf',
  'BUILD_SCRIPTS_DIR': 'build/scripts-3.12',
  'BYTESTR_DEPS': '\\',
  'CC': 'gcc -pthread',
  'CCSHARED': '-fPIC',
  'CFLAGS': '-fno-strict-overflow -Wsign-compare -DNDEBUG -O2 -I/usr/include '
-           '-I/usr/include/readline -I/usr/pkg/include -O2 -I/usr/include '
-           '-I/usr/include/readline -I/usr/pkg/include -O2 -I/usr/include '
-           '-I/usr/include/readline -I/usr/pkg/include',
+           '-I/usr/pkg/include -O2 -I/usr/include -I/usr/pkg/include -O2 '
+           '-I/usr/include -I/usr/pkg/include',
  'CFLAGSFORSHARED': '-fPIC',
  'CFLAGS_ALIASING': '',
  'CFLAGS_NODIST': '',
@@ -40,15 +39,13 @@ build_time_vars = {'ABIFLAGS': '',
  'COMPILEALL_OPTS': '-j0',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in '
                 'Makefile.pre.in',
- 'CONFIGURE_CFLAGS': '-O2 -I/usr/include -I/usr/include/readline '
-                     '-I/usr/pkg/include',
+ 'CONFIGURE_CFLAGS': '-O2 -I/usr/include -I/usr/pkg/include',
  'CONFIGURE_CFLAGS_NODIST': '-std=gnu11 -Wextra -Wno-unused-parameter '
                             '-Wno-missing-field-initializers '
                             '-Wstrict-prototypes '
                             '-Werror=implicit-function-declaration '
                             '-fvisibility=hidden',
- 'CONFIGURE_CPPFLAGS': '-I/usr/include -I/usr/include/readline '
-                       '-I/usr/pkg/include',
+ 'CONFIGURE_CPPFLAGS': '-I/usr/include -I/usr/pkg/include',
  'CONFIGURE_LDFLAGS': '-L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib '
                       '-Wl,-R/usr/pkg/lib -L/usr/X11R7/lib '
                       '-Wl,-R/usr/X11R7/lib',
@@ -57,28 +54,28 @@ build_time_vars = {'ABIFLAGS': '',
  'CONFIG_ARGS': "'--enable-shared' '--with-openssl=/usr' '--with-system-expat' "
                 "'--without-ensurepip' '--without-pymalloc' "
                 "'--with-readline=readline' '--prefix=/usr/pkg' "
-                "'--build=sparc64--netbsd' '--host=sparc64--netbsd' "
-                "'--mandir=/usr/pkg/man' '--enable-option-checking=yes' "
-                "'build_alias=sparc64--netbsd' 'host_alias=sparc64--netbsd' "
-                "'PKG_CONFIG=/tmp/pkgbuild/lang/python312/work.sparc64/.tools/bin/pkg-config' "
+                "'--build=armv6--netbsdelf-eabihf' "
+                "'--host=armv6--netbsdelf-eabihf' '--mandir=/usr/pkg/man' "
+                "'--enable-option-checking=yes' "
+                "'build_alias=armv6--netbsdelf-eabihf' "
+                "'host_alias=armv6--netbsdelf-eabihf' "
+                "'PKG_CONFIG=/pbulk/work/lang/python312/work/.tools/bin/pkg-config' "
                 "'PKG_CONFIG_PATH=' "
-                "'PKG_CONFIG_LIBDIR=/tmp/pkgbuild/lang/python312/work.sparc64/.buildlink/lib/pkgconfig:/tmp/pkgbuild/lang/python312/work.sparc64/.buildlink/share/pkgconfig' "
-                "'CC=gcc' 'CFLAGS=-O2 -I/usr/include -I/usr/include/readline "
-                "-I/usr/pkg/include' 'LDFLAGS=-L/usr/lib -Wl,-R/usr/lib "
-                '-L/usr/pkg/lib -Wl,-R/usr/pkg/lib -L/usr/X11R7/lib '
-                "-Wl,-R/usr/X11R7/lib' 'LIBS=-lcrypt' 'CPPFLAGS=-I/usr/include "
-                "-I/usr/include/readline -I/usr/pkg/include'",
+                "'PKG_CONFIG_LIBDIR=/pbulk/work/lang/python312/work/.buildlink/lib/pkgconfig:/pbulk/work/lang/python312/work/.buildlink/share/pkgconfig' "
+                "'CC=gcc' 'CFLAGS=-O2 -I/usr/include -I/usr/pkg/include' "
+                "'LDFLAGS=-L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib "
+                "-Wl,-R/usr/pkg/lib -L/usr/X11R7/lib -Wl,-R/usr/X11R7/lib' "
+                "'LIBS=-lcrypt' 'CPPFLAGS=-I/usr/include -I/usr/pkg/include'",
  'CONFINCLUDEDIR': '/usr/pkg/include',
  'CONFINCLUDEPY': '/usr/pkg/include/python3.12',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/tmp/pkgbuild/lang/python312/work.sparc64/Python-3.12.6/coverage.info',
+ 'COVERAGE_INFO': '/pbulk/work/lang/python312/work/Python-3.12.9/coverage.info',
  'COVERAGE_LCOV_OPTIONS': '--rc lcov_branch_coverage=1',
- 'COVERAGE_REPORT': '/tmp/pkgbuild/lang/python312/work.sparc64/Python-3.12.6/lcov-report',
+ 'COVERAGE_REPORT': '/pbulk/work/lang/python312/work/Python-3.12.9/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--rc lcov_branch_coverage=1 --branch-coverage '
                             '--title "CPython 3.12 LCOV report [commit $(shell '
                             ')]"',
- 'CPPFLAGS': '-I. -I./Include -I/usr/include -I/usr/include/readline '
-             '-I/usr/pkg/include -I/usr/include -I/usr/include/readline '
+ 'CPPFLAGS': '-I. -I./Include -I/usr/include -I/usr/pkg/include -I/usr/include '
              '-I/usr/pkg/include',
  'CXX': 'c++ -pthread',
  'DEEPFREEZE_C': 'Python/deepfreeze/deepfreeze.c',
@@ -100,8 +97,8 @@ build_time_vars = {'ABIFLAGS': '',
  'DLINCLDIR': '.',
  'DLLLIBRARY': '',
  'DOUBLE_IS_ARM_MIXED_ENDIAN_IEEE754': 0,
- 'DOUBLE_IS_BIG_ENDIAN_IEEE754': 1,
- 'DOUBLE_IS_LITTLE_ENDIAN_IEEE754': 0,
+ 'DOUBLE_IS_BIG_ENDIAN_IEEE754': 0,
+ 'DOUBLE_IS_LITTLE_ENDIAN_IEEE754': 1,
  'DSYMUTIL': '',
  'DSYMUTIL_PATH': '',
  'DTRACE': '',
@@ -120,7 +117,6 @@ build_time_vars = {'ABIFLAGS': '',
  'EXTRA_CFLAGS': '',
  'EXT_SUFFIX': '.so',
  'FILEMODE': 644,
- 'FLOAT_WORDS_BIGENDIAN': 1,
  'FREEZE_MODULE': './_bootstrap_python ./Programs/_freeze_module.py',
  'FREEZE_MODULE_BOOTSTRAP': './Programs/_freeze_module',
  'FREEZE_MODULE_BOOTSTRAP_DEPS': 'Programs/_freeze_module',
@@ -259,7 +255,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_GCC_ASM_FOR_MC68881': 0,
  'HAVE_GCC_ASM_FOR_X64': 0,
  'HAVE_GCC_ASM_FOR_X87': 0,
- 'HAVE_GCC_UINT128_T': 1,
+ 'HAVE_GCC_UINT128_T': 0,
  'HAVE_GDBM_DASH_NDBM_H': 0,
  'HAVE_GDBM_H': 0,
  'HAVE_GDBM_NDBM_H': 0,
@@ -327,7 +323,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_KILLPG': 1,
  'HAVE_KQUEUE': 1,
  'HAVE_LANGINFO_H': 1,
- 'HAVE_LARGEFILE_SUPPORT': 0,
+ 'HAVE_LARGEFILE_SUPPORT': 1,
  'HAVE_LCHFLAGS': 1,
  'HAVE_LCHMOD': 1,
  'HAVE_LCHOWN': 1,
@@ -429,7 +425,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_PWRITE': 1,
  'HAVE_PWRITEV': 1,
  'HAVE_PWRITEV2': 0,
- 'HAVE_READLINE_READLINE_H': 1,
+ 'HAVE_READLINE_READLINE_H': 0,
  'HAVE_READLINK': 1,
  'HAVE_READLINKAT': 1,
  'HAVE_READV': 1,
@@ -438,11 +434,11 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_RENAMEAT': 1,
  'HAVE_RL_APPEND_HISTORY': 1,
  'HAVE_RL_CATCH_SIGNAL': 1,
- 'HAVE_RL_COMPDISP_FUNC_T': 0,
+ 'HAVE_RL_COMPDISP_FUNC_T': 1,
  'HAVE_RL_COMPLETION_APPEND_CHARACTER': 1,
  'HAVE_RL_COMPLETION_DISPLAY_MATCHES_HOOK': 1,
  'HAVE_RL_COMPLETION_MATCHES': 1,
- 'HAVE_RL_COMPLETION_SUPPRESS_APPEND': 0,
+ 'HAVE_RL_COMPLETION_SUPPRESS_APPEND': 1,
  'HAVE_RL_PRE_INPUT_HOOK': 1,
  'HAVE_RL_RESIZE_TERMINAL': 1,
  'HAVE_RPC_RPC_H': 1,
@@ -553,6 +549,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_SYS_MODEM_H': 0,
  'HAVE_SYS_NDIR_H': 0,
  'HAVE_SYS_PARAM_H': 1,
+ 'HAVE_SYS_PIDFD_H': 0,
  'HAVE_SYS_POLL_H': 1,
  'HAVE_SYS_RANDOM_H': 0,
  'HAVE_SYS_RESOURCE_H': 1,
@@ -586,7 +583,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_TMPNAM_R': 0,
  'HAVE_TM_ZONE': 1,
  'HAVE_TRUNCATE': 1,
- 'HAVE_TTYNAME': 1,
+ 'HAVE_TTYNAME_R': 1,
  'HAVE_TZNAME': 0,
  'HAVE_UMASK': 1,
  'HAVE_UNAME': 1,
@@ -621,7 +618,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_ZLIB_H': 0,
  'HAVE__GETPTY': 0,
  'HOSTRUNNER': '',
- 'HOST_GNU_TYPE': 'sparc64--netbsd',
+ 'HOST_GNU_TYPE': 'armv6--netbsdelf-eabihf',
  'INCLDIRSTOMAKE': '/usr/pkg/include /usr/pkg/include '
                    '/usr/pkg/include/python3.12 /usr/pkg/include/python3.12',
  'INCLUDEDIR': '/usr/pkg/include',
@@ -655,50 +652,42 @@ build_time_vars = {'ABIFLAGS': '',
  'LIBDIR': '/usr/pkg/lib',
  'LIBEXPAT_A': 'Modules/expat/libexpat.a',
  'LIBEXPAT_CFLAGS': '-fno-strict-overflow -Wsign-compare -DNDEBUG -O2 '
-                    '-I/usr/include -I/usr/include/readline -I/usr/pkg/include '
-                    '-O2 -I/usr/include -I/usr/include/readline '
-                    '-I/usr/pkg/include -O2 -I/usr/include '
-                    '-I/usr/include/readline -I/usr/pkg/include -std=gnu11 '
-                    '-Wextra -Wno-unused-parameter '
+                    '-I/usr/include -I/usr/pkg/include -O2 -I/usr/include '
+                    '-I/usr/pkg/include -O2 -I/usr/include -I/usr/pkg/include '
+                    '-std=gnu11 -Wextra -Wno-unused-parameter '
                     '-Wno-missing-field-initializers -Wstrict-prototypes '
                     '-Werror=implicit-function-declaration '
                     '-fvisibility=hidden  -I./Include/internal -I. -I./Include '
-                    '-I/usr/include -I/usr/include/readline -I/usr/pkg/include '
-                    '-I/usr/include -I/usr/include/readline -I/usr/pkg/include '
-                    '-fPIC -fPIC',
+                    '-I/usr/include -I/usr/pkg/include -I/usr/include '
+                    '-I/usr/pkg/include -fPIC -fPIC',
  'LIBEXPAT_HEADERS': '\\',
  'LIBEXPAT_OBJS': '\\',
  'LIBHACL_CFLAGS': '-I./Modules/_hacl/include -D_BSD_SOURCE -D_DEFAULT_SOURCE '
                    '-fno-strict-overflow -Wsign-compare -DNDEBUG -O2 '
-                   '-I/usr/include -I/usr/include/readline -I/usr/pkg/include '
-                   '-O2 -I/usr/include -I/usr/include/readline '
-                   '-I/usr/pkg/include -O2 -I/usr/include '
-                   '-I/usr/include/readline -I/usr/pkg/include -std=gnu11 '
-                   '-Wextra -Wno-unused-parameter '
+                   '-I/usr/include -I/usr/pkg/include -O2 -I/usr/include '
+                   '-I/usr/pkg/include -O2 -I/usr/include -I/usr/pkg/include '
+                   '-std=gnu11 -Wextra -Wno-unused-parameter '
                    '-Wno-missing-field-initializers -Wstrict-prototypes '
                    '-Werror=implicit-function-declaration -fvisibility=hidden  '
                    '-I./Include/internal -I. -I./Include -I/usr/include '
-                   '-I/usr/include/readline -I/usr/pkg/include -I/usr/include '
-                   '-I/usr/include/readline -I/usr/pkg/include -fPIC -fPIC',
+                   '-I/usr/pkg/include -I/usr/include -I/usr/pkg/include -fPIC '
+                   '-fPIC',
  'LIBHACL_HEADERS': '\\',
  'LIBHACL_SHA2_A': 'Modules/_hacl/libHacl_Hash_SHA2.a',
  'LIBHACL_SHA2_HEADERS': '\\',
  'LIBHACL_SHA2_OBJS': '\\',
  'LIBM': '-lm',
  'LIBMPDEC_A': 'Modules/_decimal/libmpdec/libmpdec.a',
- 'LIBMPDEC_CFLAGS': '-I./Modules/_decimal/libmpdec -DCONFIG_64=1 -DANSI=1 '
-                    '-DHAVE_UINT128_T=1 -fno-strict-overflow -Wsign-compare '
-                    '-DNDEBUG -O2 -I/usr/include -I/usr/include/readline '
-                    '-I/usr/pkg/include -O2 -I/usr/include '
-                    '-I/usr/include/readline -I/usr/pkg/include -O2 '
-                    '-I/usr/include -I/usr/include/readline -I/usr/pkg/include '
+ 'LIBMPDEC_CFLAGS': '-I./Modules/_decimal/libmpdec -DCONFIG_32=1 -DANSI=1 '
+                    '-fno-strict-overflow -Wsign-compare -DNDEBUG -O2 '
+                    '-I/usr/include -I/usr/pkg/include -O2 -I/usr/include '
+                    '-I/usr/pkg/include -O2 -I/usr/include -I/usr/pkg/include '
                     '-std=gnu11 -Wextra -Wno-unused-parameter '
                     '-Wno-missing-field-initializers -Wstrict-prototypes '
                     '-Werror=implicit-function-declaration '
                     '-fvisibility=hidden  -I./Include/internal -I. -I./Include '
-                    '-I/usr/include -I/usr/include/readline -I/usr/pkg/include '
-                    '-I/usr/include -I/usr/include/readline -I/usr/pkg/include '
-                    '-fPIC -fPIC',
+                    '-I/usr/include -I/usr/pkg/include -I/usr/include '
+                    '-I/usr/pkg/include -fPIC -fPIC',
  'LIBMPDEC_HEADERS': '\\',
  'LIBMPDEC_OBJS': '\\',
  'LIBOBJDIR': 'Python/',
@@ -814,8 +803,9 @@ build_time_vars = {'ABIFLAGS': '',
  'MODULE_PYEXPAT_DEPS': '',
  'MODULE_PYEXPAT_LDFLAGS': '-lexpat',
  'MODULE_PYEXPAT_STATE': 'yes',
- 'MODULE_READLINE_CFLAGS': '',
- 'MODULE_READLINE_LDFLAGS': '-lreadline',
+ 'MODULE_READLINE_CFLAGS': '-I/usr/pkg/include',
+ 'MODULE_READLINE_LDFLAGS': '-Wl,-R/usr/pkg/lib -L/usr/pkg/lib -lreadline '
+                            '-ltermcap',
  'MODULE_READLINE_STATE': 'yes',
  'MODULE_RESOURCE_STATE': 'yes',
  'MODULE_SELECT_STATE': 'yes',
@@ -911,8 +901,8 @@ build_time_vars = {'ABIFLAGS': '',
  'MODULE__DBM_CFLAGS': '-DUSE_NDBM',
  'MODULE__DBM_LDFLAGS': '',
  'MODULE__DBM_STATE': 'yes',
- 'MODULE__DECIMAL_CFLAGS': '-I./Modules/_decimal/libmpdec -DCONFIG_64=1 '
-                           '-DANSI=1 -DHAVE_UINT128_T=1',
+ 'MODULE__DECIMAL_CFLAGS': '-I./Modules/_decimal/libmpdec -DCONFIG_32=1 '
+                           '-DANSI=1',
  'MODULE__DECIMAL_DEPS': './Modules/_decimal/docstrings.h \\ '
                          'Modules/_decimal/libmpdec/libmpdec.a',
  'MODULE__DECIMAL_LDFLAGS': '-lm Modules/_decimal/libmpdec/libmpdec.a',
@@ -1022,8 +1012,7 @@ build_time_vars = {'ABIFLAGS': '',
  'MVWDELCH_IS_EXPRESSION': 1,
  'NO_AS_NEEDED': '-Wl,--no-as-needed',
  'OBJECT_OBJS': '\\',
- 'OPT': '-DNDEBUG -O2 -I/usr/include -I/usr/include/readline '
-        '-I/usr/pkg/include',
+ 'OPT': '-DNDEBUG -O2 -I/usr/include -I/usr/pkg/include',
  'PACKAGE_BUGREPORT': 0,
  'PACKAGE_NAME': 0,
  'PACKAGE_STRING': 0,
@@ -1059,48 +1048,40 @@ build_time_vars = {'ABIFLAGS': '',
  'PYTHON_OBJS': '\\',
  'PY_BUILTIN_HASHLIB_HASHES': '"md5,sha1,sha2,sha3,blake2"',
  'PY_BUILTIN_MODULE_CFLAGS': '-fno-strict-overflow -Wsign-compare -DNDEBUG -O2 '
-                             '-I/usr/include -I/usr/include/readline '
-                             '-I/usr/pkg/include -O2 -I/usr/include '
-                             '-I/usr/include/readline -I/usr/pkg/include -O2 '
-                             '-I/usr/include -I/usr/include/readline '
-                             '-I/usr/pkg/include -std=gnu11 -Wextra '
-                             '-Wno-unused-parameter '
+                             '-I/usr/include -I/usr/pkg/include -O2 '
+                             '-I/usr/include -I/usr/pkg/include -O2 '
+                             '-I/usr/include -I/usr/pkg/include -std=gnu11 '
+                             '-Wextra -Wno-unused-parameter '
                              '-Wno-missing-field-initializers '
                              '-Wstrict-prototypes '
                              '-Werror=implicit-function-declaration '
                              '-fvisibility=hidden  -I./Include/internal -I. '
-                             '-I./Include -I/usr/include '
-                             '-I/usr/include/readline -I/usr/pkg/include '
-                             '-I/usr/include -I/usr/include/readline '
-                             '-I/usr/pkg/include -fPIC -DPy_BUILD_CORE_BUILTIN',
+                             '-I./Include -I/usr/include -I/usr/pkg/include '
+                             '-I/usr/include -I/usr/pkg/include -fPIC '
+                             '-DPy_BUILD_CORE_BUILTIN',
  'PY_CFLAGS': '-fno-strict-overflow -Wsign-compare -DNDEBUG -O2 -I/usr/include '
-              '-I/usr/include/readline -I/usr/pkg/include -O2 -I/usr/include '
-              '-I/usr/include/readline -I/usr/pkg/include -O2 -I/usr/include '
-              '-I/usr/include/readline -I/usr/pkg/include',
+              '-I/usr/pkg/include -O2 -I/usr/include -I/usr/pkg/include -O2 '
+              '-I/usr/include -I/usr/pkg/include',
  'PY_CFLAGS_NODIST': '-std=gnu11 -Wextra -Wno-unused-parameter '
                      '-Wno-missing-field-initializers -Wstrict-prototypes '
                      '-Werror=implicit-function-declaration '
                      '-fvisibility=hidden  -I./Include/internal',
  'PY_COERCE_C_LOCALE': 1,
  'PY_CORE_CFLAGS': '-fno-strict-overflow -Wsign-compare -DNDEBUG -O2 '
-                   '-I/usr/include -I/usr/include/readline -I/usr/pkg/include '
-                   '-O2 -I/usr/include -I/usr/include/readline '
-                   '-I/usr/pkg/include -O2 -I/usr/include '
-                   '-I/usr/include/readline -I/usr/pkg/include -std=gnu11 '
-                   '-Wextra -Wno-unused-parameter '
+                   '-I/usr/include -I/usr/pkg/include -O2 -I/usr/include '
+                   '-I/usr/pkg/include -O2 -I/usr/include -I/usr/pkg/include '
+                   '-std=gnu11 -Wextra -Wno-unused-parameter '
                    '-Wno-missing-field-initializers -Wstrict-prototypes '
                    '-Werror=implicit-function-declaration -fvisibility=hidden  '
                    '-I./Include/internal -I. -I./Include -I/usr/include '
-                   '-I/usr/include/readline -I/usr/pkg/include -I/usr/include '
-                   '-I/usr/include/readline -I/usr/pkg/include -fPIC '
+                   '-I/usr/pkg/include -I/usr/include -I/usr/pkg/include -fPIC '
                    '-DPy_BUILD_CORE',
  'PY_CORE_LDFLAGS': '-L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib '
                     '-Wl,-R/usr/pkg/lib -L/usr/X11R7/lib -Wl,-R/usr/X11R7/lib '
                     '-L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib '
                     '-Wl,-R/usr/pkg/lib -L/usr/X11R7/lib -Wl,-R/usr/X11R7/lib',
- 'PY_CPPFLAGS': '-I. -I./Include -I/usr/include -I/usr/include/readline '
-                '-I/usr/pkg/include -I/usr/include -I/usr/include/readline '
-                '-I/usr/pkg/include',
+ 'PY_CPPFLAGS': '-I. -I./Include -I/usr/include -I/usr/pkg/include '
+                '-I/usr/include -I/usr/pkg/include',
  'PY_ENABLE_SHARED': 1,
  'PY_HAVE_PERF_TRAMPOLINE': 0,
  'PY_LDFLAGS': '-L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib -Wl,-R/usr/pkg/lib '
@@ -1117,18 +1098,15 @@ build_time_vars = {'ABIFLAGS': '',
  'PY_SSL_DEFAULT_CIPHERS': 1,
  'PY_SSL_DEFAULT_CIPHER_STRING': 0,
  'PY_STDMODULE_CFLAGS': '-fno-strict-overflow -Wsign-compare -DNDEBUG -O2 '
-                        '-I/usr/include -I/usr/include/readline '
+                        '-I/usr/include -I/usr/pkg/include -O2 -I/usr/include '
                         '-I/usr/pkg/include -O2 -I/usr/include '
-                        '-I/usr/include/readline -I/usr/pkg/include -O2 '
-                        '-I/usr/include -I/usr/include/readline '
                         '-I/usr/pkg/include -std=gnu11 -Wextra '
                         '-Wno-unused-parameter -Wno-missing-field-initializers '
                         '-Wstrict-prototypes '
                         '-Werror=implicit-function-declaration '
                         '-fvisibility=hidden  -I./Include/internal -I. '
-                        '-I./Include -I/usr/include -I/usr/include/readline '
-                        '-I/usr/pkg/include -I/usr/include '
-                        '-I/usr/include/readline -I/usr/pkg/include -fPIC',
+                        '-I./Include -I/usr/include -I/usr/pkg/include '
+                        '-I/usr/include -I/usr/pkg/include -fPIC',
  'PY_SUPPORT_TIER': 0,
  'Py_DEBUG': 0,
  'Py_ENABLE_SHARED': 1,
@@ -1140,7 +1118,7 @@ build_time_vars = {'ABIFLAGS': '',
  'READELF': '@READELF@',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/tmp/pkgbuild/lang/python312/work.sparc64/Python-3.12.6',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/pbulk/work/lang/python312/work/Python-3.12.9',
  'SCRIPTDIR': '/usr/pkg/lib',
  'SCRIPT_2TO3': 'build/scripts-3.12/2to3-3.12',
  'SCRIPT_IDLE': 'build/scripts-3.12/idle3.12',
@@ -1186,18 +1164,18 @@ build_time_vars = {'ABIFLAGS': '',
  'SIZEOF_FLOAT': 4,
  'SIZEOF_FPOS_T': 264,
  'SIZEOF_INT': 4,
- 'SIZEOF_LONG': 8,
- 'SIZEOF_LONG_DOUBLE': 16,
+ 'SIZEOF_LONG': 4,
+ 'SIZEOF_LONG_DOUBLE': 8,
  'SIZEOF_LONG_LONG': 8,
  'SIZEOF_OFF_T': 8,
  'SIZEOF_PID_T': 4,
  'SIZEOF_PTHREAD_KEY_T': 4,
- 'SIZEOF_PTHREAD_T': 8,
+ 'SIZEOF_PTHREAD_T': 4,
  'SIZEOF_SHORT': 2,
- 'SIZEOF_SIZE_T': 8,
+ 'SIZEOF_SIZE_T': 4,
  'SIZEOF_TIME_T': 8,
- 'SIZEOF_UINTPTR_T': 8,
- 'SIZEOF_VOID_P': 8,
+ 'SIZEOF_UINTPTR_T': 4,
+ 'SIZEOF_VOID_P': 4,
  'SIZEOF_WCHAR_T': 4,
  'SIZEOF__BOOL': 1,
  'SOABI': 'cpython-312',
@@ -1218,10 +1196,10 @@ build_time_vars = {'ABIFLAGS': '',
  'SYS_SELECT_WITH_SYS_TIME': 1,
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/tmp/pkgbuild/lang/python312/work.sparc64/Python-3.12.6 '
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/pbulk/work/lang/python312/work/Python-3.12.9 '
                './python -E',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/tmp/pkgbuild/lang/python312/work.sparc64/Python-3.12.6 '
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/pbulk/work/lang/python312/work/Python-3.12.9 '
                './python -E ./Tools/scripts/run_tests.py',
  'TESTSUBDIRS': 'idlelib/idle_test \\',
  'TESTTIMEOUT': 1200,
@@ -1251,8 +1229,8 @@ build_time_vars = {'ABIFLAGS': '',
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/tmp/pkgbuild/lang/python312/work.sparc64/Python-3.12.6',
- 'abs_srcdir': '/tmp/pkgbuild/lang/python312/work.sparc64/Python-3.12.6',
+ 'abs_builddir': '/pbulk/work/lang/python312/work/Python-3.12.9',
+ 'abs_srcdir': '/pbulk/work/lang/python312/work/Python-3.12.9',
  'datarootdir': '/usr/pkg/share',
  'exec_prefix': '/usr/pkg',
  'prefix': '/usr/pkg',
